import { ModePreference, ThemeVariant, NumberFormatter } from "./system.model";
import { Accent } from "../styles/tokens";
import { OverrideStyleManager } from "../styles/override/override";
import type { ThemeDef } from "../styles/override/override.types";
export declare const STORAGE_NAME = "interchain-ui-store";
export interface UIState {
    themeMode: ModePreference;
    theme: ThemeVariant;
    themeClass: string;
    themeClasses: [string, string];
    themeAccent: Accent;
    customTheme: string | null;
    themeDefs: Array<ThemeDef>;
    overrideStyleManager: OverrideStyleManager;
    _hasHydrated: boolean;
}
export interface UIAction {
    setThemeMode: (mode: ModePreference) => void;
    setTheme: (theme: ThemeVariant, themeClass: string) => void;
    setThemeDefs: (defs: Array<ThemeDef>, defaultTheme?: string) => void;
    setCustomTheme: (customTheme: string) => void;
    setThemeAccent: (accent: Accent) => void;
    setHasHydrated: (hasHydrated: boolean) => void;
}
export interface I18nState {
    formatNumber: NumberFormatter;
}
export interface I18nAction {
    setFormatNumberFn: (fn: NumberFormatter) => void;
}
export interface UIStore extends UIState, UIAction, I18nState, I18nAction {
}
export declare const store: Omit<Omit<import("zustand/vanilla").StoreApi<UIStore>, "persist"> & {
    persist: {
        setOptions: (options: Partial<import("zustand/middleware").PersistOptions<UIStore, {
            themeMode: ModePreference;
        }>>) => void;
        clearStorage: () => void;
        rehydrate: () => void | Promise<void>;
        hasHydrated: () => boolean;
        onHydrate: (fn: (state: UIStore) => void) => () => void;
        onFinishHydration: (fn: (state: UIStore) => void) => () => void;
        getOptions: () => Partial<import("zustand/middleware").PersistOptions<UIStore, {
            themeMode: ModePreference;
        }>>;
    };
}, "setState"> & {
    setState(nextStateOrUpdater: UIStore | Partial<UIStore> | ((state: {
        themeMode: ModePreference;
        theme: ThemeVariant;
        themeClass: string;
        themeClasses: [string, string];
        themeAccent: Accent;
        customTheme: string | null;
        themeDefs: {
            name: string;
            vars: {
                colors?: {
                    black?: string;
                    blackPrimary?: string;
                    blackSecondary?: string;
                    white?: string;
                    transparent?: string;
                    current?: string;
                    whiteAlpha50?: string;
                    whiteAlpha100?: string;
                    whiteAlpha200?: string;
                    whiteAlpha300?: string;
                    whiteAlpha400?: string;
                    whiteAlpha500?: string;
                    whiteAlpha600?: string;
                    whiteAlpha700?: string;
                    whiteAlpha800?: string;
                    whiteAlpha900?: string;
                    blackAlpha50?: string;
                    blackAlpha100?: string;
                    blackAlpha200?: string;
                    blackAlpha300?: string;
                    blackAlpha400?: string;
                    blackAlpha500?: string;
                    blackAlpha600?: string;
                    blackAlpha700?: string;
                    blackAlpha800?: string;
                    blackAlpha900?: string;
                    gray50?: string;
                    gray100?: string;
                    gray200?: string;
                    gray300?: string;
                    gray400?: string;
                    gray500?: string;
                    gray600?: string;
                    gray700?: string;
                    gray800?: string;
                    gray900?: string;
                    red50?: string;
                    red100?: string;
                    red200?: string;
                    red300?: string;
                    red400?: string;
                    red500?: string;
                    red600?: string;
                    red700?: string;
                    red800?: string;
                    red900?: string;
                    orange50?: string;
                    orange100?: string;
                    orange200?: string;
                    orange300?: string;
                    orange400?: string;
                    orange500?: string;
                    orange600?: string;
                    orange700?: string;
                    orange800?: string;
                    orange900?: string;
                    yellow50?: string;
                    yellow100?: string;
                    yellow200?: string;
                    yellow300?: string;
                    yellow400?: string;
                    yellow500?: string;
                    yellow600?: string;
                    yellow700?: string;
                    yellow800?: string;
                    yellow900?: string;
                    green50?: string;
                    green100?: string;
                    green200?: string;
                    green300?: string;
                    green400?: string;
                    green500?: string;
                    green600?: string;
                    green700?: string;
                    green800?: string;
                    green900?: string;
                    blue50?: string;
                    blue100?: string;
                    blue200?: string;
                    blue300?: string;
                    blue400?: string;
                    blue500?: string;
                    blue600?: string;
                    blue700?: string;
                    blue800?: string;
                    blue900?: string;
                    primary50?: string;
                    primary100?: string;
                    primary200?: string;
                    primary300?: string;
                    primary400?: string;
                    primary500?: string;
                    primary600?: string;
                    primary700?: string;
                    primary800?: string;
                    primary900?: string;
                    purple50?: string;
                    purple100?: string;
                    purple200?: string;
                    purple300?: string;
                    purple400?: string;
                    purple500?: string;
                    purple600?: string;
                    purple700?: string;
                    purple800?: string;
                    purple900?: string;
                    accent?: "";
                    accentText?: "";
                    primary?: "";
                    body?: "";
                    background?: "";
                    link?: "";
                    linkHover?: "";
                    text?: "";
                    textInverse?: "";
                    textSecondary?: "";
                    textDanger?: "";
                    textWarning?: "";
                    textPlaceholder?: "";
                    textSuccess?: "";
                    rewardBg?: "";
                    rewardContent?: "";
                    cardBg?: "";
                    inputBorder?: "";
                    inputBorderFocus?: "";
                    inputBg?: "";
                    inputDangerBorder?: "";
                    inputDangerBg?: "";
                    inputDisabledBg?: "";
                    inputDisabledText?: "";
                    progressBg?: "";
                    progressValue?: "";
                    progressCursor?: "";
                    trackBg?: "";
                    divider?: "";
                    menuItemBg?: "";
                    menuItemBgSelected?: "";
                    menuItemBgHovered?: "";
                    menuItemBgActive?: "";
                    skeletonBg?: "";
                };
                font?: {
                    body?: "";
                };
                space?: {
                    "0"?: "";
                    "1"?: "";
                    "2"?: "";
                    "3"?: "";
                    "4"?: "";
                    "5"?: "";
                    "6"?: "";
                    "7"?: "";
                    "8"?: "";
                    "9"?: "";
                    "10"?: "";
                    "11"?: "";
                    "12"?: "";
                    "13"?: "";
                    "14"?: "";
                    "15"?: "";
                    "16"?: "";
                    "17"?: "";
                    "18"?: "";
                    "19"?: "";
                    "20"?: "";
                    "21"?: "";
                    "22"?: "";
                    "23"?: "";
                    "24"?: "";
                    "25"?: "";
                    "26"?: "";
                    "27"?: "";
                    "28"?: "";
                    "29"?: "";
                    "30"?: "";
                    auto?: "";
                    full?: "";
                    fit?: "";
                    max?: "";
                    min?: "";
                    viewHeight?: "";
                    viewWidth?: "";
                    containerSm?: "";
                    containerMd?: "";
                    containerLg?: "";
                    containerXl?: "";
                    prose?: "";
                    none?: "";
                };
                borderWidth?: {
                    none?: "";
                    sm?: "";
                    base?: "";
                    md?: "";
                    lg?: "";
                    xl?: "";
                };
                borderStyle?: {
                    none?: "";
                    solid?: "";
                    dotted?: "";
                    dashed?: "";
                    groove?: "";
                    ridge?: "";
                    hidden?: "";
                    double?: "";
                    inset?: "";
                    outset?: "";
                    unset?: "";
                };
                boxShadow?: {
                    xs?: "";
                    sm?: "";
                    base?: "";
                    md?: "";
                    lg?: "";
                    xl?: "";
                    "2xl"?: "";
                    inset?: "";
                    primaryOutline?: "";
                    none?: "";
                    "dark-lg"?: "";
                };
                radii?: {
                    none?: "";
                    sm?: "";
                    base?: "";
                    md?: "";
                    lg?: "";
                    xl?: "";
                    "2xl"?: "";
                    "3xl"?: "";
                    "4xl"?: "";
                    full?: "";
                };
                letterSpacing?: {
                    tighter?: "";
                    tight?: "";
                    normal?: "";
                    wide?: "";
                    wider?: "";
                    widest?: "";
                };
                lineHeight?: {
                    normal?: "";
                    none?: "";
                    shorter?: "";
                    short?: "";
                    base?: "";
                    tall?: "";
                    taller?: "";
                };
                fontWeight?: {
                    hairline?: "";
                    thin?: "";
                    light?: "";
                    normal?: "";
                    medium?: "";
                    semibold?: "";
                    bold?: "";
                    extrabold?: "";
                    black?: "";
                };
                fontSize?: {
                    "3xs"?: "";
                    "2xs"?: "";
                    xs?: "";
                    sm?: "";
                    md?: "";
                    lg?: "";
                    xl?: "";
                    "2xl"?: "";
                    "3xl"?: "";
                    "4xl"?: "";
                    "5xl"?: "";
                    "6xl"?: "";
                    "7xl"?: "";
                    "8xl"?: "";
                    "9xl"?: "";
                    "10xl"?: "";
                    "11xl"?: "";
                    "12xl"?: "";
                    "13xl"?: "";
                    "14xl"?: "";
                    "15xl"?: "";
                };
                zIndex?: {
                    "-1"?: "";
                    "0"?: "";
                    "10"?: "";
                    "20"?: "";
                    "30"?: "";
                    "40"?: "";
                    "50"?: "";
                    "100"?: "";
                    auto?: "";
                };
            };
        }[];
        overrideStyleManager: {
            _overrideMap: {
                button?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "clipboard-copy-text"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-install-button"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-head-title"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-wallet-button"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-wallet-button-label"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-wallet-button-sublogo"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-qr-code"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-qr-code-shadow"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-qr-code-error"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-qr-code-error-button"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
                "connect-modal-qr-code-loading"?: {
                    color?: {
                        light: string;
                        dark: string;
                    };
                    borderColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverBg?: {
                        light: string;
                        dark: string;
                    };
                    activeBg?: {
                        light: string;
                        dark: string;
                    };
                    disabledBg?: {
                        light: string;
                        dark: string;
                    };
                    focusedBg?: {
                        light: string;
                        dark: string;
                    };
                    bg?: {
                        light: string;
                        dark: string;
                    };
                    hoverColor?: {
                        light: string;
                        dark: string;
                    };
                    activeColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedColor?: {
                        light: string;
                        dark: string;
                    };
                    hoverShadow?: {
                        light: string;
                        dark: string;
                    };
                    activeShadow?: {
                        light: string;
                        dark: string;
                    };
                    disabledShadow?: {
                        light: string;
                        dark: string;
                    };
                    focusedShadow?: {
                        light: string;
                        dark: string;
                    };
                    shadow?: {
                        light: string;
                        dark: string;
                    };
                    hoverBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    activeBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    disabledBorderColor?: {
                        light: string;
                        dark: string;
                    };
                    focusedBorderColor?: {
                        light: string;
                        dark: string;
                    };
                };
            };
            _theme: ThemeVariant;
            update: (overrideMap: Partial<Record<import("../styles/override/override.types").OverridableComponents, Partial<Record<import("../styles/override/override.types").OverridableProp, {
                light: string;
                dark: string;
            }>>>>, theme: ThemeVariant) => void;
            applyOverrides: (component: import("../styles/override/override.types").OverridableComponents) => {
                [cssVarName: string]: string;
            };
        };
        _hasHydrated: boolean;
        setThemeMode: (mode: ModePreference) => void;
        setTheme: (theme: ThemeVariant, themeClass: string) => void;
        setThemeDefs: (defs: Array<ThemeDef>, defaultTheme?: string) => void;
        setCustomTheme: (customTheme: string) => void;
        setThemeAccent: (accent: Accent) => void;
        setHasHydrated: (hasHydrated: boolean) => void;
        formatNumber: NumberFormatter;
        setFormatNumberFn: (fn: NumberFormatter) => void;
    }) => void), shouldReplace?: boolean): void;
};
