import type { Children, BaseComponentProps } from "../../models/components.model";
import type { FieldLabelProps } from "../field-label/field-label.types";
import type { Sprinkles } from "../../styles/rainbow-sprinkles.css";
export type FieldLabelVariant = {
    "aria-labelledby": string;
} | {
    "aria-label": string;
} | {
    label: FieldLabelProps["label"];
};
export type FieldBaseProps = {
    id: string;
    value?: any;
    labelId?: string;
    name?: string | undefined;
    disabled?: boolean;
    autoComplete?: string | undefined;
    description?: string | undefined;
    message?: Children;
    "aria-describedby"?: string | undefined;
    data?: any;
    autoFocus?: boolean;
    prefix?: string;
    required?: boolean;
};
export type PassthroughProps = "id" | "name" | "disabled" | "autoComplete" | "autoFocus";
export interface FieldRenderProps extends Pick<FieldBaseProps, PassthroughProps> {
    background: Sprinkles["backgroundColor"];
    borderRadius: Sprinkles["borderRadius"];
    width: Sprinkles["width"];
    paddingLeft: Sprinkles["paddingLeft"];
    paddingRight: Sprinkles["paddingRight"];
    "aria-describedby"?: string;
    "aria-required"?: boolean;
    "aria-label"?: string;
    "aria-labelledby"?: string;
    className: string;
}
export type PrivateFieldProps = FieldBaseProps & FieldLabelVariant;
export declare const validTypes: {
    text: string;
    password: string;
    email: string;
    search: string;
    number: string;
    tel: string;
    url: string;
};
type InputMode = "text" | "email" | "search" | "numeric" | "tel" | "url";
export declare const defaultInputModesForType: Record<keyof typeof validTypes, InputMode>;
export interface TextFieldProps extends BaseComponentProps, FieldBaseProps {
    value: string;
    type?: keyof typeof validTypes;
    inputMode?: InputMode;
    intent?: "default" | "error";
    onChange?: (e: any) => void;
    onBlur?: (e?: any) => void;
    onFocus?: (e?: any) => void;
    onClear?: (event?: any) => void;
    size?: "sm" | "md";
    placeholder?: string | undefined;
    label?: Children | undefined;
    clearLabel?: string;
    attributes?: any;
    inputAttributes?: any;
    startAddon?: Children | undefined;
    endAddon?: Children | undefined;
    inputContainer?: string;
    inputClassName?: string;
}
export {};
